@@ -26,8 +26,8 @@ from ipywidgets.widgets.widget_description import DescriptionStyle
 from requests import HTTPError
 
 import graph_notebook
-from graph_notebook.configuration.generate_config import generate_default_config, DEFAULT_CONFIG_LOCATION, AuthModeEnum, \
-    Configuration
+from graph_notebook.configuration.generate_config import generate_default_config, DEFAULT_CONFIG_LOCATION, \
+    AuthModeEnum, Configuration
 from graph_notebook.decorators.decorators import display_exceptions, magic_variables
 from graph_notebook.magics.ml import neptune_ml_magic_handler, generate_neptune_ml_parser
 from graph_notebook.neptune.client import ClientBuilder, Client, VALID_FORMATS, PARALLELISM_OPTIONS, PARALLELISM_HIGH, \
@@ -151,14 +151,21 @@ class Graph(Magics):
         if self.client:
             self.client.close()
 
-        builder = ClientBuilder() \
-            .with_host(config.host) \
-            .with_port(config.port) \
-            .with_region(config.aws_region) \
-            .with_tls(config.ssl) \
-            .with_sparql_path(config.sparql.path)
-        if config.auth_mode == AuthModeEnum.IAM:
-            builder = builder.with_iam(get_session())
+        if ".neptune.amazonaws.com" in config.host:
+            builder = ClientBuilder() \
+                .with_host(config.host) \
+                .with_port(config.port) \
+                .with_region(config.aws_region) \
+                .with_tls(config.ssl) \
+                .with_sparql_path(config.sparql.path)
+            if config.auth_mode == AuthModeEnum.IAM:
+                builder = builder.with_iam(get_session())
+        else:
+            builder = ClientBuilder() \
+                .with_host(config.host) \
+                .with_port(config.port) \
+                .with_tls(config.ssl) \
+                .with_sparql_path(config.sparql.path)
 
         self.client = builder.build()
 
@@ -720,6 +727,8 @@ class Graph(Magics):
         parser.add_argument('-m', '--mode', choices=LOAD_JOB_MODES, default=MODE_AUTO)
         parser.add_argument('-q', '--queue-request', action='store_true', default=False)
         parser.add_argument('-d', '--dependencies', action='append', default=[])
+        parser.add_argument('-e', '--no-edge-ids', action='store_true', default=False)
+        parser.add_argument('-n', '--nopoll', action='store_true', default=False)
 
         args = parser.parse_args(line.split())
         region = self.graph_notebook_config.aws_region
@@ -739,7 +748,7 @@ class Graph(Magics):
             value=args.loader_arn,
             placeholder='Type something',
             disabled=False,
-            layout = widgets.Layout(width=widget_width)
+            layout=widgets.Layout(width=widget_width)
         )
 
         source_format = widgets.Dropdown(
@@ -749,6 +758,11 @@ class Graph(Magics):
             layout=widgets.Layout(width=widget_width)
         )
 
+        if source_format.value.lower() == 'opencypher':
+            ids_hbox_visibility = 'flex'
+        else:
+            ids_hbox_visibility = 'none'
+
         region_box = widgets.Text(
             value=region,
             placeholder=args.region,
@@ -786,9 +800,10 @@ class Graph(Magics):
 
         user_provided_edge_ids = widgets.Dropdown(
             options=['TRUE', 'FALSE'],
-            value=str(args.queue_request).upper(),
+            value=str(not args.no_edge_ids).upper(),
             disabled=False,
-            layout=widgets.Layout(width=widget_width)
+            layout=widgets.Layout(display=ids_hbox_visibility,
+                                  width=widget_width)
         )
 
         queue_request = widgets.Dropdown(
@@ -805,6 +820,13 @@ class Graph(Magics):
             layout=widgets.Layout(width=widget_width)
         )
 
+        poll_status = widgets.Dropdown(
+            options=['TRUE', 'FALSE'],
+            value=str(not args.nopoll).upper(),
+            disabled=False,
+            layout=widgets.Layout(width=widget_width)
+        )
+
         # Create a series of HBox containers that will hold the widgets and labels
         # that make up the %load form. Some of the labels and widgets are created
         # in two parts to support the validation steps that come later. In the case
@@ -812,86 +834,111 @@ class Graph(Magics):
         # HBox describing the issue.
         source_hbox_label = widgets.Label('Source:',
                                           layout=widgets.Layout(width=label_width,
-                                          display="flex",
-                                          justify_content="flex-end"))
+                                                                display="flex",
+                                                                justify_content="flex-end"))
 
-        source_hbox = widgets.HBox([source_hbox_label,source])
+        source_hbox = widgets.HBox([source_hbox_label, source])
 
         format_hbox_label = widgets.Label('Format:',
                                           layout=widgets.Layout(width=label_width,
-                                          display="flex", justify_content="flex-end"))
+                                                                display="flex",
+                                                                justify_content="flex-end"))
 
-        source_format_hbox = widgets.HBox([format_hbox_label,source_format])
+        source_format_hbox = widgets.HBox([format_hbox_label, source_format])
 
         region_hbox = widgets.HBox([widgets.Label('Region:',
-                                            layout=widgets.Layout(width=label_width,
-                                            display="flex", justify_content="flex-end")),
+                                                  layout=widgets.Layout(width=label_width,
+                                                                        display="flex",
+                                                                        justify_content="flex-end")),
                                     region_box])
 
         arn_hbox_label = widgets.Label('Load ARN:',
                                        layout=widgets.Layout(width=label_width,
-                                       display="flex",
-                                       justify_content="flex-end"))
+                                                             display="flex",
+                                                             justify_content="flex-end"))
 
         arn_hbox = widgets.HBox([arn_hbox_label, arn])
 
         mode_hbox = widgets.HBox([widgets.Label('Mode:',
-                                          layout=widgets.Layout(width=label_width,
-                                          display="flex", justify_content="flex-end")),
+                                                layout=widgets.Layout(width=label_width,
+                                                                      display="flex",
+                                                                      justify_content="flex-end")),
                                   mode])
 
         fail_hbox = widgets.HBox([widgets.Label('Fail on Error:',
-                                          layout=widgets.Layout(width=label_width,
-                                          display="flex", justify_content="flex-end")),
+                                                layout=widgets.Layout(width=label_width,
+                                                                      display="flex",
+                                                                      justify_content="flex-end")),
                                   fail_on_error])
 
         parallelism_hbox = widgets.HBox([widgets.Label('Parallelism:',
-                                                 layout=widgets.Layout(width=label_width,
-                                                 display="flex", justify_content="flex-end")),
+                                                       layout=widgets.Layout(width=label_width,
+                                                                             display="flex",
+                                                                             justify_content="flex-end")),
                                          parallelism])
 
-
         cardinality_hbox = widgets.HBox([widgets.Label('Update Single Cardinality:',
-                                                 layout=widgets.Layout(width=label_width,
-                                                 display="flex", justify_content="flex-end")),
+                                                       layout=widgets.Layout(width=label_width,
+                                                                             display="flex",
+                                                                             justify_content="flex-end")),
                                          update_single_cardinality])
 
         queue_hbox = widgets.HBox([widgets.Label('Queue Request:',
-                                           layout=widgets.Layout(width=label_width,
-                                           display="flex", justify_content="flex-end")),
+                                                 layout=widgets.Layout(width=label_width,
+                                                                       display="flex", justify_content="flex-end")),
                                    queue_request])
 
         dep_hbox_label = widgets.Label('Dependencies:',
-                                         layout=widgets.Layout(width=label_width,
-                                         display="flex", justify_content="flex-end"))
+                                       layout=widgets.Layout(width=label_width,
+                                                             display="flex", justify_content="flex-end"))
 
         dep_hbox = widgets.HBox([dep_hbox_label, dependencies])
-        
+
         ids_hbox_label = widgets.Label('User Provided Edge Ids:',
                                        layout=widgets.Layout(width=label_width,
-                                       display="flex", justify_content="flex-end"))
+                                                             display=ids_hbox_visibility,
+                                                             justify_content="flex-end"))
 
-        ids_hbox = widgets.HBox([ids_hbox_label,user_provided_edge_ids])
+        ids_hbox = widgets.HBox([ids_hbox_label, user_provided_edge_ids])
 
-        display(source_hbox, 
-                source_format_hbox, 
-                region_hbox, 
-                arn_hbox, 
-                mode_hbox, 
-                fail_hbox, 
+        poll_status_label = widgets.Label('Poll Load Status:',
+                                          layout=widgets.Layout(width=label_width,
+                                                                display="flex",
+                                                                justify_content="flex-end"))
+
+        poll_status_hbox = widgets.HBox([poll_status_label, poll_status])
+
+        def update_edge_ids_options(change):
+            if change.new.lower() == 'opencypher':
+                ids_hbox_visibility = 'flex'
+            else:
+                ids_hbox_visibility = 'none'
+                user_provided_edge_ids.value = 'TRUE'
+            user_provided_edge_ids.layout.display = ids_hbox_visibility
+            ids_hbox_label.layout.display = ids_hbox_visibility
+
+        source_format.observe(update_edge_ids_options, names='value')
+
+        display(source_hbox,
+                source_format_hbox,
+                region_hbox,
+                arn_hbox,
+                mode_hbox,
+                fail_hbox,
                 parallelism_hbox,
-                cardinality_hbox, 
-                queue_hbox, 
-                dep_hbox, 
-                ids_hbox, 
-                button, 
+                cardinality_hbox,
+                queue_hbox,
+                dep_hbox,
+                ids_hbox,
+                poll_status_hbox,
+                button,
                 output)
 
         def on_button_clicked(b):
-            source_hbox.children = (source_hbox_label,source,)
-            arn_hbox.children = (arn_hbox_label,arn,)
-            source_format_hbox.children = (format_hbox_label,source_format,)
-            dep_hbox.children = (dep_hbox_label,dependencies,)
+            source_hbox.children = (source_hbox_label, source,)
+            arn_hbox.children = (arn_hbox_label, arn,)
+            source_format_hbox.children = (format_hbox_label, source_format,)
+            dep_hbox.children = (dep_hbox_label, dependencies,)
 
             dependencies_list = list(filter(None, dependencies.value.split('\n')))
 
@@ -941,9 +988,13 @@ class Graph(Magics):
                 if dependencies:
                     kwargs['dependencies'] = dependencies_list
 
-                if source_format.value.lower()=='opencypher':
-                    kwargs['userProvidedEdgeIds']= user_provided_edge_ids.value
-                load_res = self.client.load(source.value, source_format.value, arn.value, **kwargs)
+                if source_format.value.lower() == 'opencypher':
+                    kwargs['userProvidedEdgeIds'] = user_provided_edge_ids.value
+
+                if source.value.startswith("s3://"):
+                    load_res = self.client.load(source.value, source_format.value, arn.value, **kwargs)
+                else:
+                    load_res = self.client.load(source.value, source_format.value, **kwargs)
                 load_res.raise_for_status()
                 load_result = load_res.json()
                 store_to_ns(args.store_to, load_result, local_ns)
@@ -959,10 +1010,10 @@ class Graph(Magics):
                 queue_hbox.close()
                 dep_hbox.close()
                 ids_hbox.close()
+                poll_status_hbox.close()
                 button.close()
                 output.close()
 
-
                 if 'status' not in load_result or load_result['status'] != '200 OK':
                     with output:
                         print('Something went wrong.')
@@ -970,56 +1021,65 @@ class Graph(Magics):
                         logger.error(load_result)
                     return
 
-                load_id_label = widgets.Label(f'Load ID: {load_result["payload"]["loadId"]}')
-                poll_interval = 5
-                interval_output = widgets.Output()
-                job_status_output = widgets.Output()
+                if poll_status.value == 'FALSE':
+                    start_msg_label = widgets.Label(f'Load started successfully!')
+                    polling_msg_label = widgets.Label(f'You can run "%load_status {load_result["payload"]["loadId"]}" '
+                                                      f'in another cell to check the current status of your bulk load.')
+                    start_msg_hbox = widgets.HBox([start_msg_label])
+                    polling_msg_hbox = widgets.HBox([polling_msg_label])
+                    vbox = widgets.VBox([start_msg_hbox, polling_msg_hbox])
+                    display(vbox)
+                else:
+                    poll_interval = 5
+                    load_id_label = widgets.Label(f'Load ID: {load_result["payload"]["loadId"]}')
+                    interval_output = widgets.Output()
+                    job_status_output = widgets.Output()
+                    load_id_hbox = widgets.HBox([load_id_label])
+                    status_hbox = widgets.HBox([interval_output])
+                    vbox = widgets.VBox([load_id_hbox, status_hbox, job_status_output])
+                    display(vbox)
 
-                load_id_hbox = widgets.HBox([load_id_label])
-                status_hbox = widgets.HBox([interval_output])
-                vbox = widgets.VBox([load_id_hbox, status_hbox, job_status_output])
-                display(vbox)
-
-                last_poll_time = time.time()
-                while True:
-                    time_elapsed = int(time.time() - last_poll_time)
-                    time_remaining = poll_interval - time_elapsed
-                    interval_output.clear_output()
-                    if time_elapsed > poll_interval:
-                        with interval_output:
-                            print('checking status...')
-                        job_status_output.clear_output()
-                        with job_status_output:
-                            display_html(HTML(loading_wheel_html))
-                        try:
-                            load_status_res = self.client.load_status(load_result['payload']['loadId'])
-                            load_status_res.raise_for_status()
-                            interval_check_response = load_status_res.json()
-                        except Exception as e:
-                            logger.error(e)
+                    last_poll_time = time.time()
+                    while True:
+                        time_elapsed = int(time.time() - last_poll_time)
+                        time_remaining = poll_interval - time_elapsed
+                        interval_output.clear_output()
+                        if time_elapsed > poll_interval:
+                            with interval_output:
+                                print('checking status...')
+                            job_status_output.clear_output()
                             with job_status_output:
-                                print('Something went wrong updating job status. Ending.')
-                                return
-                        job_status_output.clear_output()
-                        with job_status_output:
-                            print(f'Overall Status: {interval_check_response["payload"]["overallStatus"]["status"]}')
-                            if interval_check_response["payload"]["overallStatus"]["status"] in FINAL_LOAD_STATUSES:
-                                execution_time = interval_check_response["payload"]["overallStatus"]["totalTimeSpent"]
-                                if execution_time == 0:
-                                    execution_time_statement = '<1 second'
-                                elif execution_time > 59:
-                                    execution_time_statement = str(datetime.timedelta(seconds=execution_time))
-                                else:
-                                    execution_time_statement = f'{execution_time} seconds'
-                                print('Total execution time: ' + execution_time_statement)
-                                interval_output.close()
-                                print('Done.')
-                                return
-                        last_poll_time = time.time()
-                    else:
-                        with interval_output:
-                            print(f'checking status in {time_remaining} seconds')
-                    time.sleep(1)
+                                display_html(HTML(loading_wheel_html))
+                            try:
+                                load_status_res = self.client.load_status(load_result['payload']['loadId'])
+                                load_status_res.raise_for_status()
+                                interval_check_response = load_status_res.json()
+                            except Exception as e:
+                                logger.error(e)
+                                with job_status_output:
+                                    print('Something went wrong updating job status. Ending.')
+                                    return
+                            job_status_output.clear_output()
+                            with job_status_output:
+                                print(f'Overall Status: {interval_check_response["payload"]["overallStatus"]["status"]}')
+                                if interval_check_response["payload"]["overallStatus"]["status"] in FINAL_LOAD_STATUSES:
+                                    execution_time = interval_check_response["payload"]["overallStatus"]["totalTimeSpent"]
+                                    if execution_time == 0:
+                                        execution_time_statement = '<1 second'
+                                    elif execution_time > 59:
+                                        execution_time_statement = str(datetime.timedelta(seconds=execution_time))
+                                    else:
+                                        execution_time_statement = f'{execution_time} seconds'
+                                    print('Total execution time: ' + execution_time_statement)
+                                    interval_output.close()
+                                    print('Done.')
+                                    return
+                            last_poll_time = time.time()
+                        else:
+                            with interval_output:
+                                print(f'checking status in {time_remaining} seconds')
+                        time.sleep(1)
+
             except HTTPError as httpEx:
                 output.clear_output()
                 with output:
