@@ -19,6 +19,7 @@ logger = logging.getLogger(__file__)
 
 T_LABEL = 'T.label'
 T_ID = 'T.id'
+DEFAULT_GRP = 'DEFAULT_GROUP'
 
 INVALID_PATH_ERROR = ValueError("results must be a path with the pattern Vertex -> Edge -> Vertex.")
 INVALID_VERTEX_ERROR = ValueError("when adding a vertex, object must be of type Vertex or Dict")
@@ -58,6 +59,14 @@ def generate_id_from_dict(data: dict) -> str:
     if T.label in data.keys():
         data['label'] = data[T.label]
         del data[T.label]
+    for k in data.keys():
+        if isinstance(data[k], dict):
+            if T.id in data[k]:
+                data[k]['id'] = data[k][T.id]
+                del data[k][T.id]
+            if T.label in data[k]:
+                data[k]['label'] = data[k][T.label]
+                del data[k][T.label]
     data_str = json.dumps(data, default=str)
     hashed = hashlib.md5(data_str.encode())
     generate_id = hashed.hexdigest()
@@ -241,22 +250,27 @@ class GremlinNetwork(EventfulNetwork):
                 for i in range(len(path)):
                     if isinstance(path[i], dict):
                         is_elementmap = False
-                        for prop, value in path[i].items():
-                            if prop not in [T.id, T.label] and isinstance(value, str):
-                                is_elementmap = True
-                                break
-                            elif isinstance(value, dict):
-                                is_elementmap = True
-                                break
-                            elif isinstance(value, list):
-                                break
+                        if T.id in path[i] and T.label in path[i]:
+                            for prop, value in path[i].items():
+                                # T.id and/or T.label could be renamed by a project() step
+                                if isinstance(value, str) and prop not in [T.id, T.label]:
+                                    is_elementmap = True
+                                    break
+                                elif isinstance(value, dict):
+                                    if prop in [Direction.IN, Direction.OUT]:
+                                        is_elementmap = True
+                                        break
+                                elif isinstance(value, list):
+                                    break
+                                elif not isinstance(value, (str, list, dict)):
+                                    is_elementmap = True
+                                    break
                         if is_elementmap:
-                            self.insert_elementmap(path[i])
+                            self.insert_elementmap(path[i], check_emap=True, path_element=path, index=i)
                         else:
                             self.insert_path_element(path, i)
                     else:
                         self.insert_path_element(path, i)
-
             elif isinstance(path, dict) and T.id in path.keys() and T.label in path.keys():
                 self.insert_elementmap(path)
             else:
@@ -284,7 +298,7 @@ class GremlinNetwork(EventfulNetwork):
                 elif str(self.group_by_property) in [T_ID, 'id']:
                     group = v.id
                 else:
-                    group = ''
+                    group = DEFAULT_GRP
             else:  # handle dict format group_by
                 try:
                     if str(v.label) in self.group_by_property:
@@ -295,9 +309,9 @@ class GremlinNetwork(EventfulNetwork):
                         else:
                             group = vertex_dict[self.group_by_property[str(v.label)]]
                     else:
-                        group = ''
+                        group = DEFAULT_GRP
                 except KeyError:
-                    group = ''
+                    group = DEFAULT_GRP
 
             label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
 
@@ -324,10 +338,12 @@ class GremlinNetwork(EventfulNetwork):
             if T.label in v.keys():
                 title = str(v[T.label])
                 title_plc, label = self.strip_and_truncate_label_and_title(title, self.label_max_length)
+            else:
+                group = DEFAULT_GRP
             for k in v:
                 if str(k) == T_ID:
                     node_id = str(v[k])
-                properties[k] = v[k]
+                properties[k] = str(v[k]) if isinstance(v[k], dict) else v[k]
                 if isinstance(self.group_by_property, dict):
                     try:
                         if str(k) == self.group_by_property[title]:
@@ -344,7 +360,6 @@ class GremlinNetwork(EventfulNetwork):
                         continue
                 elif str(k) == self.display_property:
                     title, label = self.strip_and_truncate_label_and_title(str(v[k]), self.label_max_length)
-
             # handle when there is no id in a node. In this case, we will generate one which
             # is consistently regenerated so that duplicate dicts will be reduced to the same vertex.
             if node_id == '':
@@ -363,10 +378,10 @@ class GremlinNetwork(EventfulNetwork):
             node_id = str(v)
             title = str(v)
             label = title if len(title) <= self.label_max_length else title[:self.label_max_length - 3] + '...'
-            data = {'title': title, 'label': label, 'group': ''}
+            data = {'title': title, 'label': label, 'group': DEFAULT_GRP}
 
         if self.ignore_groups:
-            data['group'] = ''
+            data['group'] = DEFAULT_GRP
         self.add_node(node_id, data)
 
     def add_path_edge(self, edge, from_id='', to_id='', data=None):
@@ -467,9 +482,13 @@ class GremlinNetwork(EventfulNetwork):
 
         self.add_vertex(path[i])
         if type(path[i - 1]) is not Edge:
-            self.add_blank_edge(from_id, get_id(path[i]))
+            if type(path[i - 1]) is dict:
+                if Direction.IN not in path[i-1]:
+                    self.add_blank_edge(from_id, get_id(path[i]))
+            else:
+                self.add_blank_edge(from_id, get_id(path[i]))
 
-    def insert_elementmap(self, e_map):
+    def insert_elementmap(self, e_map, check_emap=False, path_element=None, index=None):
         """
         Add a vertex or edge that has been returned by an elementMap query step.
 
@@ -492,4 +511,7 @@ class GremlinNetwork(EventfulNetwork):
         # Handle vertex elementMap
         else:
             # Overwrite the the default node created by edge elementMap, if it exists already.
-            self.add_vertex(e_map)
+            if check_emap:
+                self.insert_path_element(path_element, index)
+            else:
+                self.add_vertex(e_map)
